SystemOrganization addCategory: #'Mason-Build'!
SystemOrganization addCategory: #'Mason-Creole'!
SystemOrganization addCategory: #'Mason-MC1'!
SystemOrganization addCategory: #'Mason-MC2'!
SystemOrganization addCategory: #'Mason-Products'!
SystemOrganization addCategory: #'Mason-Targets'!
SystemOrganization addCategory: #'Mason-Utilities'!

Object subclass: #MDBuild
	instanceVariableNames: 'directory temporaryDirectory jobs products process queue done'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Build'!

!MDBuild class methodsFor: 'as yet unclassified' stamp: 'cwp 1/5/2009 21:25'!
example
	| squeak packages |
	squeak := '/Users/colin/Projects/Squeak' asPath.
	packages := squeak / 'package-cache'.
	MDBuild run:
		[:root |
		root directory:
			[:dev |
			dev path: 'development'.
			dev image:
				[:ide |
				ide name: 'ide'.
				ide baseImage: squeak / 'base' / 'Squeak3.10.2-7179-basic' / 'Squeak3.10.2-7179-basic.image'.
				ide script path: squeak / 'scripts' / 'base-image-cleanup-3.10.cs'.
				ide mc1 path: packages / 'AST-lr.157.mcz'.
				ide mc1 path: packages / 'RefactoringEngine-lr.46.mcz'.
				ide mc1 path: packages / 'VB-Regex-sd.9.mcz'.
				ide mc1 path: packages / 'OmniBrowser-lr.407.mcz'.
				ide mc1 path: packages / 'OB-Morphic-lr.45.mcz'.
				ide mc1 path: packages / 'OB-Standard-lr.323.mcz'.
				ide mc1 path: packages / 'OB-Refactory-lr.113.mcz'.
				ide mc1 path: packages / 'OB-Regex-lr.9.mcz'].
			dev image:
				[:tests |
				tests name: 'tests'.
				tests baseImage: 'ide'.
				tests mc1 path: packages / 'Bogus-cwp.18.mcz'.
				tests mc1 path: packages / 'BogusExt-cwp.3.mcz'.
				tests mc1 path: packages / 'BogusInfo-cwp.17.mcz'.
				tests mc1 path: packages / 'OB-Fake-lr.9.mcz'.
				tests mc1 path: packages / 'OB-Tests-Core-cwp.65.mcz'.
				tests mc1 path: packages / 'OB-Tests-Morphic-cwp.16.mcz'.
				tests mc1 path: packages / 'OB-Tests-Standard-cwp.85.mcz'].
			dev tests:
				[:testrun |
				testrun name: 'testrun'.
				testrun imagePath: 'tests'.
				testrun suite package: 'OB-Tests']]]

! !

!MDBuild class methodsFor: 'as yet unclassified' stamp: 'cwp 1/5/2009 21:50'!
run: aBlock 
	(MDTarget with: aBlock) createBuild runAndWait! !

!MDBuild class methodsFor: 'as yet unclassified' stamp: 'cwp 1/5/2009 22:15'!
runScript: anObject 
	| path script target build |
	path := anObject asPath.
	script := (FileStream oldFileNamed: path asString) contentsOfEntireFile.
	target := Compiler evaluate: script.
	build := MDBuild new.
	build directory: path parent.
	target addAllJobsTo: build.
	build runAndWait! !

!MDBuild methodsFor: 'initialization' stamp: 'cwp 12/14/2008 16:22'!
addJob: aJob
	jobs add: aJob.
	! !

!MDBuild methodsFor: 'accessing' stamp: 'cwp 12/22/2008 20:42'!
allProducts
	^ jobs
		inject: Set new
		into: 
			[:all :ea | 
			all addAll: ea supplies.
			all]! !

!MDBuild methodsFor: 'accessing' stamp: 'cwp 12/22/2008 20:43'!
allRequirements
	^ jobs
		inject: Set new
		into: 
			[:all :ea | 
			all addAll: ea requires.
			all]! !

!MDBuild methodsFor: 'running' stamp: 'cwp 1/13/2009 21:59'!
assureDirectories
	directory asReference exists ifFalse: 
		[self error: 'directory ' , directory asString , ' does not exist.'].
	MDCreateDirectoryJob new
		path: temporaryDirectory;
		runIn: self! !

!MDBuild methodsFor: 'running' stamp: 'cwp 12/16/2008 09:13'!
canRunJob: job 
	^ job canRun and: [ job requires allSatisfy: [ :ea | products includes: ea ] ]! !

!MDBuild methodsFor: 'initialization' stamp: 'cwp 6/1/2009 21:35'!
chooseTemporaryDirectory
	| name count path |
	name := self name.
	count := 1.
	path := FSPath defaultDirectory / name , count asString.
	[ path asReference exists ] whileTrue: 
		[ count := count + 1.
		path := path , count asString ].
	^ path! !

!MDBuild methodsFor: 'running' stamp: 'cwp 12/22/2008 21:43'!
delete: aPath
	| parent basename |
	parent := FileDirectory on: aPath parent asString.
	basename := aPath basename.
	(parent directoryExists: basename) 
		ifTrue: [(FileDirectory on: aPath asString) recursiveDelete]
		ifFalse:
			[(parent fileExists: basename)
				ifTrue: [parent deleteFileNamed: basename]]! !

!MDBuild methodsFor: 'accessing' stamp: 'cwp 12/14/2008 16:22'!
directory
	^ directory! !

!MDBuild methodsFor: 'accessing' stamp: 'cwp 12/14/2008 11:29'!
directory: aPath
	directory := aPath! !

!MDBuild methodsFor: 'initialization' stamp: 'cwp 6/1/2009 21:35'!
initialize
	jobs := Set new.
	directory := FSPath defaultDirectory.
	temporaryDirectory := self chooseTemporaryDirectory.
	queue := SharedQueue new! !

!MDBuild methodsFor: 'initialization' stamp: 'cwp 12/16/2008 07:42'!
name
	^ 'build-' , self identityHash printString! !

!MDBuild methodsFor: 'running' stamp: 'cwp 1/13/2009 22:00'!
prepareToRun
	| internal external |
	self assureDirectories.
	internal := self allProducts.
	external := self allRequirements difference: internal.
	products := Set new.
	internal do: [:ea | self delete: ea].
	external do:
		[:path | 
		path asReference exists
			ifTrue: [products add: path]
			ifFalse: [self error: 'Missing requirement: ', path asString]]! !

!MDBuild methodsFor: 'running' stamp: 'cwp 12/16/2008 23:02'!
recognize: aJob
	products addAll: aJob supplies.
	self scanJobs.! !

!MDBuild methodsFor: 'running' stamp: 'cwp 12/19/2008 03:18'!
run
	self runSignalling: Semaphore new! !

!MDBuild methodsFor: 'running' stamp: 'cwp 12/16/2008 08:56'!
run: aJob
	| message |
	aJob 
		runIn: self 
		signalWith: 
			[message := Message selector: #recognize: argument: aJob.
			queue nextPut: message]! !

!MDBuild methodsFor: 'running' stamp: 'cwp 1/5/2009 21:50'!
runAndWait
	| sem |
	sem := Semaphore new.
	self runSignalling: sem.
	sem wait.! !

!MDBuild methodsFor: 'running' stamp: 'cwp 12/16/2008 23:04'!
runLoop
	| message |
	done := false.
	[done] whileFalse:
		[message := queue next.
		message sendTo: self]! !

!MDBuild methodsFor: 'running' stamp: 'cwp 1/5/2009 21:49'!
runSignalling: aSemaphore 
	self prepareToRun.
	self scanJobs.
	process := 
		[self runLoop.
		aSemaphore signal] 
			forkAt: Processor userBackgroundPriority
			named: self name! !

!MDBuild methodsFor: 'running' stamp: 'cwp 12/22/2008 16:13'!
scanJobs
	done := true.
	jobs do: 
		[ :job | 
		job isComplete ifFalse: 
			[ done := false.
			(self canRunJob: job) ifTrue: [ self run: job ] ] ].
	done ifTrue: [ jobs do: [ :ea | ea done ] ]! !

!MDBuild methodsFor: 'running' stamp: 'cwp 12/16/2008 09:08'!
schedule: aJob
	| message |
	message := Message selector: #run: argument: aJob.
	queue nextPut: message.! !

!MDBuild methodsFor: 'running' stamp: 'cwp 12/16/2008 23:59'!
stop
	jobs do: [:ea | ea stop].
	done := true.
	queue nextPut: (Message selector: #yourself)! !

!MDBuild methodsFor: 'accessing' stamp: 'cwp 12/15/2008 12:14'!
temporaryDirectory
	^ temporaryDirectory! !

Object subclass: #MDJob
	instanceVariableNames: 'state process'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Build'!

MDJob subclass: #MDCreateDirectoryJob
	instanceVariableNames: 'path'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Build'!

!MDCreateDirectoryJob methodsFor: 'accessing' stamp: 'cwp 12/14/2008 18:03'!
path
	^ path! !

!MDCreateDirectoryJob methodsFor: 'accessing' stamp: 'cwp 12/15/2008 14:27'!
path: anObject
	path := anObject asPath! !

!MDCreateDirectoryJob methodsFor: 'running' stamp: 'cwp 1/13/2009 22:15'!
runIn: aBuild
	path asReference ensureDirectory! !

!MDCreateDirectoryJob methodsFor: 'dependencies' stamp: 'cwp 12/14/2008 18:04'!
supplies
	^ Set with: path! !

MDJob subclass: #MDFileJob
	instanceVariableNames: 'source dest'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Build'!

MDFileJob subclass: #MDCopyFileJob
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Build'!

!MDCopyFileJob methodsFor: 'as yet unclassified' stamp: 'cwp 7/23/2009 23:57'!
run
	source asReference copyTo: dest asReference! !

!MDFileJob class methodsFor: 'as yet unclassified' stamp: 'cwp 1/10/2009 23:18'!
source: sourcePath dest: destPath
	^ self new setSource: sourcePath dest: destPath! !

!MDFileJob methodsFor: 'dependencies' stamp: 'cwp 1/10/2009 22:52'!
requires
	^ Set 
		with: dest parent 
		with: source! !

!MDFileJob methodsFor: 'initialize-release' stamp: 'cwp 1/10/2009 22:52'!
setSource: sourcePath dest: destPath
	source := sourcePath.
	dest := destPath! !

!MDFileJob methodsFor: 'dependencies' stamp: 'cwp 1/10/2009 22:53'!
supplies
	^ Set with: dest! !

MDFileJob subclass: #MDRenderCreoleJob
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Creole'!

!MDRenderCreoleJob methodsFor: 'accessing' stamp: 'cwp 1/10/2009 23:42'!
cssRef
	^ dest parent basename, '.css'! !

!MDRenderCreoleJob methodsFor: 'running' stamp: 'cwp 1/10/2009 13:20'!
parseCreole
	| in |
	[in := FileStream oldFileNamed: source asString.
	^ CreoleDocumentParser parseFrom: in]
		ensure: [in ifNotNil: [in close]].
	! !

!MDRenderCreoleJob methodsFor: 'running' stamp: 'cwp 1/10/2009 22:40'!
run
	| node |
	node := self parseCreole.
	CreoleLinker link: node at: dest parent asString, '/'.
	self writeHtml: node! !

!MDRenderCreoleJob methodsFor: 'initialize-release' stamp: 'cwp 1/10/2009 23:20'!
setSource: sourcePath dest: destPath
	source := sourcePath.
	dest := destPath, 'html'! !

!MDRenderCreoleJob methodsFor: 'accessing' stamp: 'cwp 1/10/2009 13:30'!
title
	| basename words |
	basename := source basename.
	(basename endsWith: '.creole') ifTrue:
		[basename := basename allButLast: 7].
	words := String streamContents:
		[:out | 
		basename do:
			[:character |
			character isUppercase ifTrue: [out space].
			out nextPut: character]].
	^ words withBlanksCondensed withBlanksTrimmed! !

!MDRenderCreoleJob methodsFor: 'running' stamp: 'cwp 1/10/2009 13:25'!
writeFooterOn: aStream
	aStream nextPutAll: '</body></html>'! !

!MDRenderCreoleJob methodsFor: 'running' stamp: 'cwp 1/10/2009 23:44'!
writeHeaderOn: aStream
	aStream
		nextPutAll: '<html><head><title>';
		nextPutAll: self title;
		nextPutAll: '</title><link rel="stylesheet" href="';
		nextPutAll: self cssRef;
		nextPutAll: '" type="text/css" media="screen" charset="utf-8"></head><body>'! !

!MDRenderCreoleJob methodsFor: 'running' stamp: 'cwp 1/10/2009 22:31'!
writeHtml: aNode
	| out |
	[out := FileStream newFileNamed: dest asString.
	self writeHeaderOn: out.
	CreoleHtmlPrinter print: aNode on: out.
	self writeFooterOn: out]
		ensure: [out ifNotNil: [out close]]! !

!MDJob methodsFor: 'running' stamp: 'cwp 12/14/2008 23:23'!
addToBuild: aBuild
	aBuild addJob: self! !

!MDJob methodsFor: 'running' stamp: 'cwp 12/16/2008 23:45'!
canRun
	^ state = #notYetRunning! !

!MDJob methodsFor: 'running' stamp: 'cwp 12/16/2008 23:43'!
done
	process := nil.
	state := #notYetRunning! !

!MDJob methodsFor: 'initialize-release' stamp: 'cwp 12/16/2008 23:40'!
initialize
	state := #notYetRunning! !

!MDJob methodsFor: 'running' stamp: 'cwp 12/16/2008 23:45'!
isComplete
	^ state = #complete! !

!MDJob methodsFor: 'dependencies' stamp: 'cwp 12/14/2008 16:31'!
requires
	^ Set new! !

!MDJob methodsFor: 'running' stamp: 'cwp 1/10/2009 13:18'!
run
	self subclassResponsibility! !

!MDJob methodsFor: 'running' stamp: 'cwp 12/16/2008 08:57'!
runIn: aBuild
	self run! !

!MDJob methodsFor: 'running' stamp: 'cwp 12/22/2008 19:08'!
runIn: aBuild signalWith: aBlock
	state = #notYetRunning ifFalse: [self error: 'Job is already running'].
	state := #running.
	process := 
		[self runIn: aBuild.
		state := #complete.
		aBlock value]
			forkAt: Processor userBackgroundPriority - 1
			named: self name.! !

!MDJob methodsFor: 'running' stamp: 'cwp 12/16/2008 23:55'!
stop
	process ifNotNil:
		[process terminate.
		process := nil.
		state := #interrupted].
	self canRun ifTrue: [state := #cancelled]! !

!MDJob methodsFor: 'dependencies' stamp: 'cwp 12/14/2008 16:32'!
supplies
	^ Set new! !

MDJob subclass: #MDRunScriptJob
	instanceVariableNames: 'scripts targetImage baseImage'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Build'!

!MDRunScriptJob methodsFor: 'accessing' stamp: 'cwp 12/13/2008 23:25'!
addScript: aPath
	scripts add: aPath! !

!MDRunScriptJob methodsFor: 'accessing' stamp: 'cwp 12/19/2008 13:37'!
baseImagePath
	^ baseImage ! !

!MDRunScriptJob methodsFor: 'accessing' stamp: 'cwp 12/19/2008 13:37'!
baseImagePath: aPath
	baseImage := aPath! !

!MDRunScriptJob methodsFor: 'accessing' stamp: 'cwp 12/19/2008 13:37'!
changesPath
	^ self targetImagePath , 'changes'! !

!MDRunScriptJob methodsFor: 'accessing' stamp: 'cwp 12/19/2008 13:38'!
imagePath
	^ self targetImagePath , 'image'! !

!MDRunScriptJob methodsFor: 'intialize-release' stamp: 'cwp 12/14/2008 11:39'!
initialize
	super initialize.
	scripts := OrderedCollection new.! !

!MDRunScriptJob methodsFor: 'accessing' stamp: 'cwp 12/20/2008 12:09'!
name
	^ self imagePath basename! !

!MDRunScriptJob methodsFor: 'dependencies' stamp: 'cwp 12/19/2008 13:40'!
requires
	^ Set new
		add: self baseImagePath;
		add: self targetImagePath parent;
		addAll: scripts;
		yourself! !

!MDRunScriptJob methodsFor: 'running' stamp: 'cwp 12/20/2008 10:55'!
runIn: aBuild 
	| loadScript |
	loadScript := aBuild temporaryDirectory / targetImage basename , 'st'.
	self writeLoadScript: loadScript.
	self runLoadScript: loadScript! !

!MDRunScriptJob methodsFor: 'running' stamp: 'cwp 12/31/2008 14:01'!
runLoadScript: scriptPath 
	| arguments proc d |
	d := Delay forMilliseconds: 50.
	arguments := Array 
		with: self baseImagePath asString
		with: scriptPath printString.
	proc := OSProcess thisOSProcess 
		forkJob: OSProcess programName
		arguments: arguments
		environment: nil
		descriptors: nil.
	proc ifNil: [ OSProcess noAccessorAvailable ].
	[ proc runState == #complete ] whileFalse: [ d wait ]! !

!MDRunScriptJob methodsFor: 'dependencies' stamp: 'cwp 12/15/2008 14:08'!
supplies
	^ Set 
		with: targetImage
		with: targetImage , 'changes'! !

!MDRunScriptJob methodsFor: 'accessing' stamp: 'cwp 12/15/2008 14:08'!
targetImagePath
	^ targetImage! !

!MDRunScriptJob methodsFor: 'accessing' stamp: 'cwp 12/15/2008 14:08'!
targetImagePath: anObject 
	targetImage := anObject asPath! !

!MDRunScriptJob methodsFor: 'running' stamp: 'cwp 12/31/2008 13:31'!
writeFilein: aPath on: aStream 
	aStream
		cr;
		nextPut: $!!;
		cr;
		cr;
		nextPutAll: '(FileStream oldFileNamed: ''';
		print: aPath;
		nextPutAll: ''') fileIn; close';
		cr! !

!MDRunScriptJob methodsFor: 'running' stamp: 'cwp 7/24/2009 00:48'!
writeLoadScript: scriptPath 
	scriptPath asReference fileStreamDo:
		[:stream | self writeScriptOn: stream]! !

!MDRunScriptJob methodsFor: 'running' stamp: 'cwp 12/19/2008 13:26'!
writePostscriptOn: aStream
	self writePostscriptOn: aStream saving: true! !

!MDRunScriptJob methodsFor: 'running' stamp: 'cwp 12/19/2008 13:38'!
writePostscriptOn: aStream saving: aBoolean
	aStream
		cr; nextPut: $!!; cr; cr;
		nextPutAll: 'SmalltalkImage current snapshot: ';
		print: aBoolean;
		nextPutAll: ' andQuit: true.';
		cr! !

!MDRunScriptJob methodsFor: 'running' stamp: 'cwp 12/19/2008 13:39'!
writePreambleOn: aStream
	aStream 
		nextPutAll: '(SourceFiles at: 2) ifNotNil:'; cr;
		tab; nextPutAll: '[SmalltalkImage current'; cr;
		tab; tab; nextPutAll: 'closeSourceFiles;'; cr;
		tab; tab; nextPutAll: 'saveChangesInFileNamed: '''; 
		print: self changesPath;
		nextPutAll: '''].'; cr; cr;
		nextPutAll: 'SmalltalkImage current'; cr;
		tab; nextPutAll: 'changeImageNameTo: '''; 
		print: self imagePath;
		nextPutAll: ''';'; cr;
		tab; nextPutAll: 'closeSourceFiles;'; cr;
		tab; nextPutAll: 'openSourceFiles.'; cr.
! !

!MDRunScriptJob methodsFor: 'running' stamp: 'cwp 12/19/2008 13:26'!
writeScriptBodyOn: aStream 
	scripts do: 
		[ :ea | 
		self 
			writeFilein: ea
			on: aStream ]! !

!MDRunScriptJob methodsFor: 'running' stamp: 'cwp 12/19/2008 13:39'!
writeScriptOn: aStream 
	self writePreambleOn: aStream.
	self writeScriptBodyOn: aStream.
	self writePostscriptOn: aStream! !

MDJob subclass: #MDWriteScriptJob
	instanceVariableNames: 'path'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Build'!

MDWriteScriptJob subclass: #MDFileoutSnapshotsJob
	instanceVariableNames: 'store references'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-MC2'!

!MDFileoutSnapshotsJob methodsFor: 'accessing' stamp: 'cwp 12/31/2008 11:23'!
addRepository: aRepository 
	(store repositories includes: aRepository) ifFalse: 
		[ store addRepository: aRepository ].! !

!MDFileoutSnapshotsJob methodsFor: 'accessing' stamp: 'cwp 12/31/2008 11:36'!
addSnapshotReference: aHashstamp 
	references add: aHashstamp! !

!MDFileoutSnapshotsJob methodsFor: 'accessing' stamp: 'cwp 12/31/2008 11:39'!
addSnapshotTarget: aTarget 
	self addRepository: aTarget repository.
	self addSnapshotReference: aTarget snapshotReference! !

!MDFileoutSnapshotsJob methodsFor: 'initialize-release' stamp: 'cwp 12/31/2008 11:33'!
initialize
	super initialize.
	store := MDStore new.
	references := Set new! !

!MDFileoutSnapshotsJob methodsFor: 'accessing' stamp: 'cwp 12/31/2008 11:12'!
repository
	^ store! !

!MDFileoutSnapshotsJob methodsFor: 'running' stamp: 'cwp 12/31/2008 12:27'!
run
	super run.
	store repositories do: [:ea | ea close]! !

!MDFileoutSnapshotsJob methodsFor: 'accessing' stamp: 'cwp 12/31/2008 11:36'!
snapshots
	^ references collect: [:ea | store get: ea]! !

!MDFileoutSnapshotsJob methodsFor: 'running' stamp: 'cwp 12/31/2008 12:27'!
writeOn: stream 
	| exporter |
	exporter := MDFileOutExporter on: stream.
	self snapshots do: 
		[ :snapshot | 
		(snapshot getVersionsFrom: store) do: 
			[:version | exporter addVersion: version]].
	exporter harmonize.
	exporter flush! !

MDWriteScriptJob subclass: #MDMczJob
	instanceVariableNames: 'mcz'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-MC1'!

!MDMczJob methodsFor: 'accessing' stamp: 'cwp 12/23/2008 13:29'!
mcz
	^ mcz! !

!MDMczJob methodsFor: 'accessing' stamp: 'cwp 12/23/2008 13:29'!
mcz: anObject
	mcz := anObject asPath! !

!MDMczJob methodsFor: 'as yet unclassified' stamp: 'cwp 7/14/2009 00:44'!
requires
	^ Set with: self path parent! !

!MDMczJob methodsFor: 'running' stamp: 'cwp 12/23/2008 13:53'!
writeOn: aStream
	| zip member |
	zip := ZipArchive new readFrom: self mcz asString.
	member := zip memberNamed: 'snapshot/source.st'.
	member extractTo: aStream.
	! !

!MDWriteScriptJob methodsFor: 'accessing' stamp: 'cwp 12/23/2008 12:10'!
addScriptTo: aRunScriptJob 
	aRunScriptJob addScript: self path! !

!MDWriteScriptJob methodsFor: 'accessing' stamp: 'cwp 12/20/2008 12:01'!
name
	^ self path basename! !

!MDWriteScriptJob methodsFor: 'accessing' stamp: 'cwp 12/19/2008 13:48'!
path
	^ path! !

!MDWriteScriptJob methodsFor: 'accessing' stamp: 'cwp 12/19/2008 13:49'!
path: anObject
	path := anObject asPath! !

!MDWriteScriptJob methodsFor: 'running' stamp: 'cwp 7/24/2009 00:54'!
run
	path asReference fileStreamDo: [:stream | self writeOn: stream]! !

!MDWriteScriptJob methodsFor: 'dependencies' stamp: 'cwp 12/19/2008 13:48'!
supplies
	^ Set with: self path! !

!MDWriteScriptJob methodsFor: 'running' stamp: 'cwp 12/19/2008 13:48'!
writeOn: stream
	self subclassResponsibility! !

MDWriteScriptJob subclass: #MDWriteTestScriptJob
	instanceVariableNames: 'packages report'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Build'!

!MDWriteTestScriptJob methodsFor: 'running' stamp: 'cwp 12/22/2008 18:34'!
fileOutRunnerOn: aStream 
	MDTestRunner fileOutOn: aStream.
	aStream cr.! !

!MDWriteTestScriptJob methodsFor: 'accessing' stamp: 'cwp 12/20/2008 00:39'!
packages
	^ packages! !

!MDWriteTestScriptJob methodsFor: 'accessing' stamp: 'cwp 12/20/2008 00:39'!
packages: anObject
	packages := anObject! !

!MDWriteTestScriptJob methodsFor: 'accessing' stamp: 'cwp 12/20/2008 01:19'!
report
	^ report! !

!MDWriteTestScriptJob methodsFor: 'accessing' stamp: 'cwp 12/20/2008 01:19'!
report: anObject
	report := anObject! !

!MDWriteTestScriptJob methodsFor: 'running' stamp: 'cwp 12/20/2008 00:43'!
writeOn: aStream 
	self fileOutRunnerOn: aStream.
	self writeRunCommandOn: aStream! !

!MDWriteTestScriptJob methodsFor: 'running' stamp: 'cwp 12/20/2008 10:53'!
writeRunCommandOn: aStream 
	aStream
		nextPutAll: 'MDTestRunner new';
		cr;
		tab;
		nextPutAll: 'path: ''';
		print: self report;
		nextPutAll: ''';';
		cr.
	self packages do: 
		[ :pkg | 
		aStream
			tab;
			nextPutAll: 'addPackageNamed: ';
			print: pkg;
			nextPut: $;;
			cr ].
	aStream
		tab;
		nextPutAll: 'run';
		cr! !

Object subclass: #MDProduct
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Products'!

MDProduct subclass: #MDCwpProduct
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Products'!

!MDCwpProduct methodsFor: 'paths' stamp: 'cwp 7/13/2009 15:04'!
baseImagePath
	^ self libraryPath / 'base' / 'Squeak3.10.2-7179-basic' / 'Squeak3.10.2-7179-basic.image'! !

!MDCwpProduct methodsFor: 'paths' stamp: 'cwp 7/13/2009 15:04'!
libraryPath
	^ FSPath root / 'Users' / 'colin' / 'Library' / 'Squeak'! !

!MDCwpProduct methodsFor: 'paths' stamp: 'cwp 7/13/2009 15:11'!
masonRepositoryPath
	^ FSPath root / 'Users' / 'colin' / 'Projects' / 'Mason' / 'mason.mcr'! !

!MDCwpProduct methodsFor: 'paths' stamp: 'cwp 7/14/2009 00:31'!
repositoryPath
	^ self libraryPath / 'package-cache'! !

!MDCwpProduct methodsFor: 'paths' stamp: 'cwp 7/13/2009 15:05'!
scriptsPath
	^ self libraryPath / 'scripts'! !

MDCwpProduct subclass: #MDIdeProduct
	instanceVariableNames: 'packages'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Products'!

!MDIdeProduct methodsFor: 'as yet unclassified' stamp: 'cwp 7/12/2009 04:51'!
initialize
	packages := '/Users/colin/Library/Squeak/package-cache' asPath.
! !

!MDIdeProduct methodsFor: 'as yet unclassified' stamp: 'cwp 7/12/2009 04:52'!
specifyOn: targets
	targets mc1 path: packages / 'AST-lr.157.mcz'.
	targets mc1 path: packages / 'RefactoringEngine-lr.46.mcz'.
	targets mc1 path: packages / 'VB-Regex-sd.9.mcz'.
	targets mc1 path: packages / 'OmniBrowser-dr.434.mcz'.
	targets mc1 path: packages / 'OB-Standard-lr.372.mcz'.
	targets mc1 path: packages / 'OB-Morphic-dkh.67.mcz'.
	targets mc1 path: packages / 'OB-Refactory-lr.113.mcz'.
	targets mc1 path: packages / 'OB-Regex-lr.9.mcz'.
	targets mc1 path: packages / 'OB-SUnitGUI-dkh.41.mcz'.
! !

MDCwpProduct subclass: #MDMc2DevProduct
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Products'!

!MDMc2DevProduct methodsFor: 'paths' stamp: 'cwp 7/12/2009 05:08'!
mc2ReleasePath
	^ FSPath root
		/ 'Users'
		/ 'colin'
		/ 'Projects'
		/ 'Monticello2'
		/ 'releases'
		/ 'Monticello-2.0.31'! !

!MDMc2DevProduct methodsFor: 'specifying' stamp: 'cwp 8/8/2009 10:51'!
specifyOn: targets 
	targets directory
		path: 'development';
		with: 
			[ targets image
				name: 'ide';
				baseImage: self baseImagePath;
				with: 
					[ targets script path: self scriptsPath / 'remove-mc1.st'.
					targets script path: self scriptsPath / 'base-image-cleanup-3.10.cs'.
					targets specify: MDIdeProduct.
					targets script path: self mc2ReleasePath / '1-Monticello2.st'] ]! !

MDCwpProduct subclass: #MDMc2DistProduct
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Products'!

!MDMc2DistProduct methodsFor: 'as yet unclassified' stamp: 'cwp 7/12/2009 05:20'!
devPath
	^ FSPath root
		/ 'Users'
		/ 'colin'
		/ 'Projects'
		/ 'Monticello2'
		! !

!MDMc2DistProduct methodsFor: 'as yet unclassified' stamp: 'cwp 7/13/2009 18:32'!
specifyOn: targets
	targets directory path: self versionString; with:
		[targets file
			path: self devPath / 'mc.mcr';
			jobClass: MDCopyFileJob.
		targets directory path: 'extras'; with: 
			[targets file
				path: self scriptsPath / 'remove-mc1.st';
				jobClass: MDCopyFileJob.
			targets file
				path: self scriptsPath / 'remove-mc2.st';
				jobClass: MDCopyFileJob].
		targets directory path: 'docs'; with:
			[targets files
				directoryPath: self devPath / 'docs';
				pattern: '*.creole';
				jobClass: MDRenderCreoleJob.
			targets file
				path: self devPath / 'docs' / 'docs.css';
				jobClass: MDCopyFileJob.
			targets directory path: 'images'; with:
				[targets files
					directoryPath: self devPath / 'docs' / 'images';
					pattern: '*.png';
					jobClass: MDCopyFileJob]]]! !

!MDMc2DistProduct methodsFor: 'as yet unclassified' stamp: 'cwp 7/13/2009 18:29'!
versionString
	^ 'Monticello-2.0.30'! !

MDCwpProduct subclass: #MDMiniMasonProduct
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Products'!

!MDMiniMasonProduct methodsFor: 'as yet unclassified' stamp: 'cwp 7/13/2009 15:21'!
specifyOn: targets
	targets directory path: 'distribution'; with:
		[targets image
			name: 'mason';
			baseImage: '/Users/colin/Projects/Squeak/KernelImageMC/KernelImageMC.image';
			with:
				[targets script path: '/Users/colin/Projects/Squeak/scripts/remove-mc1.st'.
				targets 
					sliceName: 'Monticello2';
					repositoryPath: '/Users/colin/Projects/Squeak/Alexandria/images/mc.mcr'.
				targets latest
					sliceName: 'SUnit';
					repositoryPath: '/Users/colin/Projects/Squeak/Mason/ide.mcr'.
				targets latest
					sliceName: 'Mason';
					repositoryPath: '/Users/colin/Projects/Squeak/Mason/mason.mcr']]! !

MDCwpProduct subclass: #MDOBDevProduct
	instanceVariableNames: 'packages'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Products'!

!MDOBDevProduct methodsFor: 'as yet unclassified' stamp: 'cwp 7/13/2009 15:12'!
initialize
	packages := self libraryPath / 'package-cache'! !

!MDOBDevProduct methodsFor: 'as yet unclassified' stamp: 'cwp 7/13/2009 15:06'!
specifyOn: targets
	targets directory path: 'development'; with:
		[targets image
			name: 'ide'; 
			baseImage: self baseImagePath;
			with: [targets specify: MDIdeProduct].
		targets image
			name: 'tests';
			baseImage: 'ide';
			with:
				[targets mc1 path: packages / 'Bogus-cwp.18.mcz'.
				targets mc1 path: packages / 'BogusExt-cwp.3.mcz'.
				targets mc1 path: packages / 'BogusInfo-cwp.17.mcz'.
				targets mc1 path: packages / 'OB-Fake-lr.9.mcz'.
				targets mc1 path: packages / 'OB-Tests-Core-cwp.65.mcz'.
				targets mc1 path: packages / 'OB-Tests-Morphic-cwp.16.mcz'.
				targets mc1 path: packages / 'OB-Tests-Standard-cwp.85.mcz'].
		targets tests 
			name: 'testrun';
			imagePath: 'tests';
			with: [targets suite package: 'OB-Tests']]
! !

MDCwpProduct subclass: #MDOBDistProduct
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Products'!

!MDOBDistProduct methodsFor: 'accessing' stamp: 'cwp 8/3/2009 09:00'!
devDirectory
	^ FSPath / 'Users' / 'colin' / 'Projects' / 'OmniBrowser'! !

!MDOBDistProduct methodsFor: 'accessing' stamp: 'cwp 8/27/2009 22:18'!
mczFilenames
	^#(
		'OmniBrowser-lr.453' 
		'OB-Morphic-cwp.100' 
		'OB-Standard-cwp.428'
		'OB-Shout-cwp.1'
		
		'AST-Gwenael_Casaccio.215'
		'Refactoring-Core-lr.57'
		'Refactoring-Spelling-lr.6'
		'VB-Regex-damienpollet.17'
		'OB-Refactory-lr.159'
		'OB-Regex-lr.19'
		
		'OB-SUnitIntegration-lr.14'
	)! !

!MDOBDistProduct methodsFor: 'paths' stamp: 'cwp 7/14/2009 00:54'!
pathForVersionName: name 
	^ self repositoryPath / (name , '.mcz')! !

!MDOBDistProduct methodsFor: 'accessing' stamp: 'cwp 7/14/2009 01:01'!
scriptName: name index: index 
	^ String streamContents:
		[:out |
		index printOn: out base: 10 length: 2 padded: true.
		out nextPut: $-;
			nextPutAll: (name copyUpToLast: $-);
			nextPutAll: '.st']
	! !

!MDOBDistProduct methodsFor: 'specifying' stamp: 'cwp 8/27/2009 22:18'!
specifyDocsOn: targets 
	targets file
		jobClass: MDCopyFileJob new;
		path: self devDirectory / 'build' / 'README.txt'.
		
	targets file
		jobClass: MDCopyFileJob new;
		path: self devDirectory / 'build' / 'ReleaseNotes.txt'! !

!MDOBDistProduct methodsFor: 'specifying' stamp: 'cwp 8/3/2009 08:47'!
specifyFileoutsOn: targets 
	^ self mczFilenames withIndexDo: 
		[ :name :index | 
		targets mczFileout
			path: (self pathForVersionName: name);
			name: (self 
					scriptName: name
					index: index) ]! !

!MDOBDistProduct methodsFor: 'specifying' stamp: 'cwp 8/3/2009 08:48'!
specifyOn: targets 
	targets directory
		path: self versionString;
		with: 
			[self specifyDocsOn: targets.
			self specifyFileoutsOn: targets]! !

!MDOBDistProduct methodsFor: 'accessing' stamp: 'cwp 8/27/2009 21:58'!
versionString
	^ 'OmniBrowser-2.0.3'! !

!MDProduct class methodsFor: 'as yet unclassified' stamp: 'cwp 7/12/2009 04:53'!
build
	^ self new build! !

!MDProduct class methodsFor: 'as yet unclassified' stamp: 'cwp 7/12/2009 05:25'!
specifyOn: targets
	^ self new specifyOn: targets! !

!MDProduct methodsFor: 'as yet unclassified' stamp: 'cwp 7/14/2009 00:40'!
build
	self target createBuild run! !

!MDProduct methodsFor: 'as yet unclassified' stamp: 'cwp 7/12/2009 04:44'!
specifyOn: targets! !

!MDProduct methodsFor: 'as yet unclassified' stamp: 'cwp 7/12/2009 04:44'!
target
	| canvas |
	canvas := MDTargetCanvas new.
	self specifyOn: canvas.
	^ canvas current! !

Object subclass: #MDTarget
	instanceVariableNames: 'parent children'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

MDTarget subclass: #MDDirectoryTarget
	instanceVariableNames: 'path'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDDirectoryTarget methodsFor: 'build' stamp: 'cwp 1/10/2009 23:31'!
addJobsTo: aBuild
	MDCreateDirectoryJob new
		path: (aBuild directory resolve: self pathInContext);
		addToBuild: aBuild! !

!MDDirectoryTarget methodsFor: 'testing' stamp: 'cwp 1/10/2009 23:28'!
isDirectory	
	^ true! !

!MDDirectoryTarget methodsFor: 'accessing' stamp: 'cwp 12/15/2008 14:20'!
path
	^ path! !

!MDDirectoryTarget methodsFor: 'accessing' stamp: 'cwp 12/15/2008 12:40'!
path: anObject
	path := anObject asPath! !

!MDDirectoryTarget methodsFor: 'accessing' stamp: 'cwp 1/10/2009 23:55'!
pathInContext
	^ parent isDirectory
		ifTrue: [parent pathInContext resolve: path]
		ifFalse: [path]! !

MDTarget subclass: #MDFileSystemTarget
	instanceVariableNames: 'jobClass'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDFileSystemTarget methodsFor: 'accessing' stamp: 'cwp 1/10/2009 23:08'!
jobClass
	^ jobClass! !

!MDFileSystemTarget methodsFor: 'accessing' stamp: 'cwp 1/10/2009 23:08'!
jobClass: anObject
	jobClass := anObject! !

MDFileSystemTarget subclass: #MDFileTarget
	instanceVariableNames: 'path'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDFileTarget methodsFor: 'build' stamp: 'cwp 1/10/2009 23:35'!
addJobsTo: aBuild
	| job |
	job := MDCopyFileJob
		source: (aBuild directory resolve: path)
		dest: (aBuild directory resolve: parent pathInContext) / path basename.
	job addToBuild: aBuild! !

!MDFileTarget methodsFor: 'accessing' stamp: 'cwp 1/10/2009 23:14'!
path
	^ path! !

!MDFileTarget methodsFor: 'accessing' stamp: 'cwp 1/10/2009 23:14'!
path: anObject
	path := anObject asPath! !

MDFileSystemTarget subclass: #MDFilesTarget
	instanceVariableNames: 'directoryPath pattern'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDFilesTarget methodsFor: 'as yet unclassified' stamp: 'cwp 1/10/2009 23:36'!
addJobsTo: aBuild 
	| sourcePath sourceDir source dest destPath |
	sourcePath := aBuild directory resolve: directoryPath.
	destPath := aBuild directory resolve: parent pathInContext.
	sourceDir := FileDirectory on: sourcePath asString.
	(sourceDir fileNamesMatching: pattern) do: 
		[ :name | 
		source := sourcePath / name.
		dest := destPath / name.
		aBuild addJob: (jobClass source: source dest: dest) ]! !

!MDFilesTarget methodsFor: 'accessing' stamp: 'cwp 1/9/2009 18:13'!
directoryPath
	^ directoryPath! !

!MDFilesTarget methodsFor: 'accessing' stamp: 'cwp 1/9/2009 18:17'!
directoryPath: anObject
	directoryPath := anObject asPath! !

!MDFilesTarget methodsFor: 'accessing' stamp: 'cwp 1/9/2009 18:13'!
pattern
	^ pattern! !

!MDFilesTarget methodsFor: 'accessing' stamp: 'cwp 1/9/2009 18:13'!
pattern: anObject
	pattern := anObject! !

MDTarget subclass: #MDImageContentTarget
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDImageContentTarget methodsFor: 'jobs' stamp: 'cwp 12/23/2008 14:05'!
queueJobsIn: jobs build: aBuild name: aString
	self subclassResponsibility! !

!MDImageContentTarget methodsFor: 'jobs' stamp: 'cwp 6/1/2009 21:35'!
scriptPathIn: aPath basename: aString ordinal: anInteger
	| name |
	name := String streamContents:
		[:out |
		out nextPutAll: (aString copyUpToLast: FSPath extensionDelimiter).
		out nextPut: $-.
		out print: anInteger.
		out nextPutAll: '.st'].
	^ aPath / name! !

MDImageContentTarget subclass: #MDLatestSnapshotTarget
	instanceVariableNames: 'repositoryPath sliceName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDLatestSnapshotTarget methodsFor: 'jobs' stamp: 'cwp 12/31/2008 11:31'!
addJobToQueue: jobs path: aPath name: aString
	| path job |
	path := self scriptPathIn: aPath basename: aString ordinal: jobs size + 1.
	job := MDFileoutSnapshotsJob new
		path: path;
		addSnapshotTarget: self;
		yourself.
	jobs add: job! !

!MDLatestSnapshotTarget methodsFor: 'testing' stamp: 'cwp 12/31/2008 12:03'!
memoMatches: aMemo
	^ aMemo sliceName = sliceName! !

!MDLatestSnapshotTarget methodsFor: 'jobs' stamp: 'cwp 12/23/2008 12:04'!
queueJobsIn: jobs build: aBuild name: aString
	(jobs isEmpty or: [jobs last class ~= MDFileoutSnapshotsJob])
		ifTrue: [self addJobToQueue: jobs path: aBuild temporaryDirectory name: aString]
		ifFalse: [jobs last addSnapshotTarget: self]
	! !

!MDLatestSnapshotTarget methodsFor: 'jobs' stamp: 'cwp 12/31/2008 12:13'!
repository
	^ MDFileRepository on: self repositoryStream! !

!MDLatestSnapshotTarget methodsFor: 'jobs' stamp: 'cwp 12/31/2008 12:13'!
repositoryDo: aBlock
	^ MDFileRepository
		on: self repositoryStream
		do: aBlock! !

!MDLatestSnapshotTarget methodsFor: 'accessing' stamp: 'cwp 12/31/2008 11:59'!
repositoryPath: anObject
	repositoryPath := anObject asPath! !

!MDLatestSnapshotTarget methodsFor: 'jobs' stamp: 'cwp 12/31/2008 12:13'!
repositoryStream
	^ FileStream oldFileNamed: repositoryPath asString! !

!MDLatestSnapshotTarget methodsFor: 'accessing' stamp: 'cwp 12/31/2008 12:00'!
sliceName: aString
	sliceName := aString! !

!MDLatestSnapshotTarget methodsFor: 'jobs' stamp: 'cwp 12/31/2008 12:05'!
snapshotReference
	| memos latest |
	memos := self repositoryDo:
		[:repository |
		repository memos select: [:ea | self memoMatches: ea]].
	latest := memos
		inject: memos anyOne
		into: 
			[:memo :each |
			(each <= memo)
				ifTrue: [memo]
				ifFalse: [each]].
	^ latest reference! !

MDImageContentTarget subclass: #MDMczFileinTarget
	instanceVariableNames: 'path'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-MC1'!

!MDMczFileinTarget methodsFor: 'accessing' stamp: 'cwp 12/23/2008 12:49'!
path
	^ path! !

!MDMczFileinTarget methodsFor: 'accessing' stamp: 'cwp 12/23/2008 12:49'!
path: anObject
	path := anObject asPath! !

!MDMczFileinTarget methodsFor: 'jobs' stamp: 'cwp 6/1/2009 21:44'!
queueJobsIn: queue build: aBuild name: aString
	| script job |
	script := self 
		scriptPathIn: aBuild temporaryDirectory 
		basename: aString 
		ordinal: queue size + 1.
	job := MDMczJob new
		path: script;
		mcz: (FSPath resolve: self path);
		yourself.
	queue add: job.! !

MDImageContentTarget subclass: #MDMczFileoutTarget
	instanceVariableNames: 'path name'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-MC1'!

!MDMczFileoutTarget methodsFor: 'as yet unclassified' stamp: 'cwp 7/13/2009 23:33'!
addJobsTo: aBuild
	
	MDMczJob new
		path: (aBuild directory resolve: parent pathInContext) / name;
		mcz: (FSPath resolve: self path);
		addToBuild: aBuild! !

!MDMczFileoutTarget methodsFor: 'accessing' stamp: 'cwp 7/13/2009 23:25'!
name
	^ name! !

!MDMczFileoutTarget methodsFor: 'accessing' stamp: 'cwp 7/13/2009 23:25'!
name: anObject
	name := anObject! !

!MDMczFileoutTarget methodsFor: 'accessing' stamp: 'cwp 7/13/2009 23:25'!
path
	^ path! !

!MDMczFileoutTarget methodsFor: 'accessing' stamp: 'cwp 7/13/2009 23:25'!
path: anObject
	path := anObject! !

MDImageContentTarget subclass: #MDScriptTarget
	instanceVariableNames: 'path'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDScriptTarget methodsFor: 'accessing' stamp: 'cwp 6/1/2009 21:35'!
addScriptTo: aRunScriptJob 
	aRunScriptJob addScript: (FSPath resolve: self path)! !

!MDScriptTarget methodsFor: 'accessing' stamp: 'cwp 12/23/2008 14:01'!
addToBuild: aBuild
	! !

!MDScriptTarget methodsFor: 'accessing' stamp: 'cwp 12/23/2008 14:03'!
path
	^ path! !

!MDScriptTarget methodsFor: 'accessing' stamp: 'cwp 12/23/2008 14:03'!
path: anObject
	path := anObject asPath! !

!MDScriptTarget methodsFor: 'accessing' stamp: 'cwp 12/23/2008 14:01'!
queueJobsIn: queue build: aBuild name: aString
	queue add: self! !

MDTarget subclass: #MDImageTarget
	instanceVariableNames: 'name baseImage'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDImageTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/23/2008 12:10'!
addJobsTo: aBuild 
	| jobs |
	jobs := children 
		inject: OrderedCollection new
		into: 
			[ :queue :job | 
			job queueJobsIn: queue build: aBuild name: name.
			queue ].
	MDRunScriptJob new
		baseImagePath: (aBuild directory resolve: self baseImagePath);
		targetImagePath: (aBuild directory resolve: self targetImagePath);
		in: [ :run | jobs do: [ :job | job addScriptTo: run ] ];
		addToBuild: aBuild.
	jobs do: [ :ea | ea addToBuild: aBuild ]! !

!MDImageTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 12:05'!
baseImage: anObject
	baseImage := anObject! !

!MDImageTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 12:05'!
baseImagePath
	^ (parent path resolve: baseImage asPath), 'image'! !

!MDImageTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/14/2008 22:15'!
name
	^ name! !

!MDImageTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 10:28'!
name: aString
	name := aString! !

!MDImageTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 10:28'!
targetImagePath
	^ (parent path / name) assureExtension: 'image'! !

MDTarget subclass: #MDRootTarget
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDTarget class methodsFor: 'as yet unclassified' stamp: 'cwp 1/3/2009 21:58'!
with: aBlock 
	| target |
	target := self new.
	aBlock value: target.
	^ target! !

!MDTarget methodsFor: 'build' stamp: 'cwp 12/14/2008 23:18'!
addAllJobsTo: aBuild
	self addJobsTo: aBuild.
	children do: [:ea | ea addAllJobsTo: aBuild].! !

!MDTarget methodsFor: 'accessing' stamp: 'cwp 1/3/2009 22:30'!
addChild: aTarget 
	^ self addChild: aTarget with: [:target]! !

!MDTarget methodsFor: 'accessing' stamp: 'cwp 1/3/2009 22:30'!
addChild: aTarget with: aBlock
	aTarget parent: self.
	children add: aTarget.
	aBlock value: aTarget.
	^ aTarget! !

!MDTarget methodsFor: 'build' stamp: 'cwp 12/14/2008 23:18'!
addJobsTo: aBuild
	! !

!MDTarget methodsFor: 'build' stamp: 'cwp 1/3/2009 22:02'!
createBuild
	| build |
	build := MDBuild new.
	self addAllJobsTo: build.
	^ build! !

!MDTarget methodsFor: 'initialize-release' stamp: 'cwp 12/14/2008 22:05'!
initialize
	children := OrderedCollection new.! !

!MDTarget methodsFor: 'testing' stamp: 'cwp 1/10/2009 23:28'!
isDirectory
	^ false! !

!MDTarget methodsFor: 'accessing' stamp: 'cwp 12/14/2008 19:55'!
parent
	^ parent! !

!MDTarget methodsFor: 'accessing' stamp: 'cwp 1/3/2009 22:09'!
parent: aTarget
	parent := aTarget.
	! !

!MDTarget methodsFor: 'accessing' stamp: 'cwp 6/1/2009 21:36'!
path
	^ FSPath new! !

!MDTarget methodsFor: 'targets' stamp: 'cwp 7/12/2009 00:29'!
root
	^ parent root! !

!MDTarget methodsFor: 'targets' stamp: 'cwp 7/12/2009 00:34'!
with: aBlock
	^ self root current: self do: aBlock! !

MDTarget subclass: #MDTestRunTarget
	instanceVariableNames: 'name image'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDTestRunTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 10:48'!
addJobsTo: aBuild 
	| script |
	script := aBuild temporaryDirectory / self scriptName.
	MDWriteTestScriptJob new
		path: script;
		report: (aBuild directory resolve: self reportPath);
		packages: self packageNames;
		addToBuild: aBuild.
	MDRunScriptJob new
		baseImagePath: (aBuild directory resolve: self baseImagePath);
		targetImagePath: (aBuild directory resolve: self targetImagePath);
		addScript: script;
		addToBuild: aBuild! !

!MDTestRunTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 10:31'!
baseImagePath
	^ (parent path / image) assureExtension: 'image'! !

!MDTestRunTarget methodsFor: 'as yet unclassified' stamp: 'cwp 1/3/2009 22:37'!
imagePath: aString
	image := aString! !

!MDTestRunTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 00:49'!
name: aString
	name := aString! !

!MDTestRunTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 01:14'!
packageNames
	^ children collect: [:ea | ea package]! !

!MDTestRunTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 01:24'!
reportPath
	^ parent path / name , 'txt'! !

!MDTestRunTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/22/2008 17:56'!
scriptName
	^ name , '-1.st'! !

!MDTestRunTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 10:32'!
targetImagePath
	^ (parent path / name) assureExtension: 'image'! !

MDTarget subclass: #MDTestSuiteTarget
	instanceVariableNames: 'package'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDTestSuiteTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 01:07'!
package
	^ package! !

!MDTestSuiteTarget methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 00:51'!
package: aString
	package := aString! !

Object subclass: #MDTargetCanvas
	instanceVariableNames: 'stack current'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Targets'!

!MDTargetCanvas methodsFor: 'accessing' stamp: 'cwp 7/12/2009 00:42'!
addChild: aTarget 
	current addChild: aTarget.
	^ aTarget! !

!MDTargetCanvas methodsFor: 'accessing' stamp: 'cwp 7/12/2009 00:42'!
addChild: aTarget with: aBlock
	current addChild: aTarget.
	self current: aTarget do: aBlock.
	^ aTarget! !

!MDTargetCanvas methodsFor: 'accessing' stamp: 'cwp 7/12/2009 00:35'!
current
	^ current! !

!MDTargetCanvas methodsFor: 'accessing' stamp: 'cwp 7/12/2009 00:34'!
current: aTarget do: aBlock
	| previous |
	previous := current.
	current := aTarget.
	aBlock ensure: [current := previous]! !

!MDTargetCanvas methodsFor: 'targets' stamp: 'cwp 7/12/2009 00:43'!
directory
	^ self addChild: MDDirectoryTarget new 
		! !

!MDTargetCanvas methodsFor: 'targets' stamp: 'cwp 7/12/2009 00:43'!
file
	^ self addChild: MDFileTarget new! !

!MDTargetCanvas methodsFor: 'targets' stamp: 'cwp 7/12/2009 00:43'!
files
	^ self addChild: MDFilesTarget new! !

!MDTargetCanvas methodsFor: 'targets' stamp: 'cwp 7/12/2009 00:43'!
image
	^ self addChild: MDImageTarget new
		! !

!MDTargetCanvas methodsFor: 'initialize-release' stamp: 'cwp 7/12/2009 00:35'!
initialize
	
	current := MDRootTarget new.
	current parent: self.
	! !

!MDTargetCanvas methodsFor: 'targets' stamp: 'cwp 7/12/2009 00:43'!
latest
	^ self addChild: MDLatestSnapshotTarget new ! !

!MDTargetCanvas methodsFor: 'targets' stamp: 'cwp 7/13/2009 22:51'!
mc1
	^ self addChild: MDMczFileinTarget new! !

!MDTargetCanvas methodsFor: 'targets' stamp: 'cwp 7/14/2009 00:30'!
mczFileout
	^ self addChild: MDMczFileoutTarget new! !

!MDTargetCanvas methodsFor: 'accessing' stamp: 'cwp 7/12/2009 00:14'!
root
	^ self! !

!MDTargetCanvas methodsFor: 'targets' stamp: 'cwp 7/12/2009 00:44'!
script
	^ self addChild: MDScriptTarget new
		! !

!MDTargetCanvas methodsFor: 'accessing' stamp: 'cwp 7/12/2009 21:39'!
specify: anObject
	anObject specifyOn: self! !

!MDTargetCanvas methodsFor: 'targets' stamp: 'cwp 7/12/2009 00:44'!
suite
	^ self addChild: MDTestSuiteTarget new
		! !

!MDTargetCanvas methodsFor: 'targets' stamp: 'cwp 7/12/2009 00:44'!
tests
	^ self addChild: MDTestRunTarget new
		! !

Object variableSubclass: #MDTestRunner
	instanceVariableNames: 'packages path'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mason-Utilities'!

!MDTestRunner methodsFor: 'as yet unclassified' stamp: 'cwp 12/19/2008 23:46'!
addPackageNamed: aString
	packages add: (PackageInfo named: aString)! !

!MDTestRunner methodsFor: 'as yet unclassified' stamp: 'cwp 12/19/2008 23:56'!
buildSuite
	| suite all |
	suite := TestSuite new.
	all := TestCase buildSuite.
	all tests do: 
		[:test |
		(packages anySatisfy: [:pkg | pkg includesMethod: test selector ofClass: test class])
			ifTrue: [suite addTest: test]].
	^ suite! !

!MDTestRunner methodsFor: 'as yet unclassified' stamp: 'cwp 12/19/2008 23:46'!
initialize
	packages := Set new! !

!MDTestRunner methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 11:06'!
path: aString
	path := aString! !

!MDTestRunner methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 12:18'!
run
	| result initials |
	initials := Utilities authorInitialsPerSe.
	[Utilities setAuthorInitials: 'test runner'.
	result := self buildSuite run.
	self writeResult: result]
		ensure: [Utilities setAuthorInitials: initials].! !

!MDTestRunner methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 11:06'!
writeResult: aResult
	FileStream 
		forceNewFileNamed: path 
		do: [:stream | self writeResult: aResult on: stream] ! !

!MDTestRunner methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 22:46'!
writeResult: aResult on: aStream
	aStream
		nextPutAll: 'Test Result, ';
		nextPutAll: (TimeStamp now asString);
		cr;
		print: aResult;
		cr.
	
	self writeTests: aResult errors as: 'Errors' on: aStream.
	self writeTests: aResult failures as: 'Failures' on: aStream.! !

!MDTestRunner methodsFor: 'as yet unclassified' stamp: 'cwp 12/20/2008 22:46'!
writeTests: aCollection as: aString on: aStream
	aCollection isEmpty ifTrue: [^ self].
	aStream 
		cr;
		nextPutAll: aString;
		cr.
	aCollection do:
		[:test |
		aStream 
			nextPutAll: test class name;
			nextPutAll: '>>';
			nextPutAll: test selector;
			cr]! !
